==> pointpos_api-0.2.1.tar.gz: test/merchant_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for MerchantApi
void main() {
  var instance = new MerchantApi();

  group('tests for MerchantApi', () {
    // Merchant Change Password
    //
    // Merchant Change Password
    //
    //Future<Token> changePassword(String xAPIKey, String authorization, ChangePassword body) async 
    test('test changePassword', () async {
      // TODO
    });

    // Check Reset Token
    //
    // Check Reset Token
    //
    //Future checkResetToken(String xAPIKey, String resetToken) async 
    test('test checkResetToken', () async {
      // TODO
    });

    // Merchant Forgot Password
    //
    // Merchant Forgot Password
    //
    //Future forgotPassword(String xAPIKey, ForgotPassword body) async 
    test('test forgotPassword', () async {
      // TODO
    });

    // Merchant Get Profile
    //
    // Merchant Get Profile
    //
    //Future<Profile> getProfile(String xAPIKey, String authorization) async 
    test('test getProfile', () async {
      // TODO
    });

    // Merchant Login
    //
    // Merchant Login
    //
    //Future<Token> login(String xAPIKey, Login body) async 
    test('test login', () async {
      // TODO
    });

    // Refresh Session
    //
    // Refresh Session
    //
    //Future<Token> refreshToken(String xAPIKey, String authorization, { RefreshToken body }) async 
    test('test refreshToken', () async {
      // TODO
    });

    // Resend Email Verification
    //
    // Resend Email Verification
    //
    //Future resendEmailVerification(String xAPIKey, ResendEmailVerification body) async 
    test('test resendEmailVerification', () async {
      // TODO
    });

    // Merchant Reset Password
    //
    // Merchant Reset Password
    //
    //Future resetPassword(String xAPIKey, ResetPassword body) async 
    test('test resetPassword', () async {
      // TODO
    });

    // Merchant Signup
    //
    // Merchant Signup
    //
    //Future signup(String xAPIKey, Signup body) async 
    test('test signup', () async {
      // TODO
    });

    // Merchant Update Profile
    //
    // Merchant Update Profile
    //
    //Future<Token> updateProfile(UpdateProfile body) async 
    test('test updateProfile', () async {
      // TODO
    });

    // Email Verification
    //
    // Email Verification
    //
    //Future verification(String xAPIKey, String token) async 
    test('test verification', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.2.tar.gz: test/merchant_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for MerchantApi
void main() {
  var instance = new MerchantApi();

  group('tests for MerchantApi', () {
    // Merchant Change Password
    //
    // Merchant Change Password
    //
    //Future<Token> changePassword(String xAPIKey, String authorization, ChangePassword body) async 
    test('test changePassword', () async {
      // TODO
    });

    // Check Reset Token
    //
    // Check Reset Token
    //
    //Future checkResetToken(String xAPIKey, String resetToken) async 
    test('test checkResetToken', () async {
      // TODO
    });

    // Merchant Forgot Password
    //
    // Merchant Forgot Password
    //
    //Future forgotPassword(String xAPIKey, ForgotPassword body) async 
    test('test forgotPassword', () async {
      // TODO
    });

    // Merchant Get Profile
    //
    // Merchant Get Profile
    //
    //Future<Profile> getProfile(String xAPIKey, String authorization) async 
    test('test getProfile', () async {
      // TODO
    });

    // Merchant Login
    //
    // Merchant Login
    //
    //Future<Token> login(String xAPIKey, Login body) async 
    test('test login', () async {
      // TODO
    });

    // Refresh Session
    //
    // Refresh Session
    //
    //Future<Token> refreshToken(String xAPIKey, String authorization, { RefreshToken body }) async 
    test('test refreshToken', () async {
      // TODO
    });

    // Resend Email Verification
    //
    // Resend Email Verification
    //
    //Future resendEmailVerification(String xAPIKey, ResendEmailVerification body) async 
    test('test resendEmailVerification', () async {
      // TODO
    });

    // Merchant Reset Password
    //
    // Merchant Reset Password
    //
    //Future resetPassword(String xAPIKey, ResetPassword body) async 
    test('test resetPassword', () async {
      // TODO
    });

    // Merchant Signup
    //
    // Merchant Signup
    //
    //Future signup(String xAPIKey, Signup body) async 
    test('test signup', () async {
      // TODO
    });

    // Merchant Update Profile
    //
    // Merchant Update Profile
    //
    //Future<Token> updateProfile(String xAPIKey, String authorization, UpdateProfile body) async 
    test('test updateProfile', () async {
      // TODO
    });

    // Email Verification
    //
    // Email Verification
    //
    //Future verification(String xAPIKey, String token) async 
    test('test verification', () async {
      // TODO
    });

  });
}
